@@ -201,13 +201,15 @@ utils.install_packages('Cairo')
     def eval(self, code):
         '''
         Parse and evaluate a line of R code with rpy2.
-        Returns the output to R's stdout() connection, 
+        Returns the output to R's stdout() connection,
         the value generated by evaluating the code, and a
         boolean indicating whether the return value would be
         visible if the line of code were evaluated in an R REPL.
 
         R Code evaluation and visibility determination are done via an R call of
-        the form withVisible(eval(parse(code_string)))
+        the form withVisible(code_string), and this entire expression needs to
+        be evaluated in R (we can't use rpy2 function proxies here, as
+        withVisible is a LISPy R function).
 
         '''
         old_writeconsole = ri.get_writeconsole()
@@ -319,8 +321,7 @@ utils.install_packages('Cairo')
         args = parse_argstring(self.Rpull, line)
         outputs = args.outputs
         for output in outputs:
-            self.shell.push({output:
-                             ro.conversion.ri2ro(ro.r(output)) })
+            self.shell.push({output: ro.r(output) })
 
     # @skip_doctest
     @magic_arguments()
@@ -351,7 +352,7 @@ utils.install_packages('Cairo')
         '''
         args = parse_argstring(self.Rget, line)
         output = args.output
-        return ro.conversion.ri2ro(ro.r(output[0]))
+        return ro.r(output[0])
 
 
     def setup_graphics(self, args):
@@ -451,7 +452,7 @@ utils.install_packages('Cairo')
         )
     @argument(
         '-o', '--output', action='append',
-        help='Names of variables to be pushed from rpy2 to shell.user_ns after executing cell body and applying ro.conversion.ri2ro. Multiple names can be passed separated only by commas with no whitespace.'
+        help="Names of variables to be pushed from rpy2 to shell.user_ns after executing cell body (rpy2's internal facilities will apply ri2ro as appropriate). Multiple names can be passed separated only by commas with no whitespace."
         )
     @argument(
         '-n', '--noreturn',
@@ -658,8 +659,7 @@ utils.install_packages('Cairo')
 
         if args.output:
             for output in ','.join(args.output).split(','):
-                self.shell.push({output:
-                                 ro.conversion.ri2ro(ro.r(output)) })
+                self.shell.push({output: ro.r(output) })
 
 
         # this will keep a reference to the display_data
@@ -672,8 +672,8 @@ utils.install_packages('Cairo')
         # We're in line mode and return_output is still True, 
         # so return the converted result
         if return_output and not args.noreturn:
-            if result != ri.NULL:
-                return ro.conversion.ri2ro(result)
+            if result is not ri.NULL:
+                return result
 
 __doc__ = __doc__.format(
                 R_DOC = ' '*8 + RMagics.R.__doc__,
