@@ -7,10 +7,6 @@ import numpy
 
 #from rpy2.robjects.vectors import DataFrame, Vector, ListVector
 
-original_py2ri = None
-original_ri2ro = None
-original_py2ro = None 
-
 # The possible kind codes are listed at
 #   http://numpy.scipy.org/array_interface.shtml
 _kinds = {
@@ -70,6 +66,7 @@ def numpy2ri(o):
             for field_name in o.dtype.names:
                 df_args.append((field_name, 
                                 conversion.py2ri(o[field_name])))
+            # XXX: Note that an .rcall() currently calls .default_ri2ro!
             res = ro.baseenv["data.frame"].rcall(tuple(df_args), ro.globalenv)
         # It should be impossible to get here:
         else:
@@ -87,7 +84,10 @@ def numpy2ro(o):
     return res
     
 def ri2numpy(o):
-    if isinstance(o, ListSexpVector):
+    # XXX: data.frames are ending up as SexpVectors - not ListSexpVectors
+    # I changed this conditional, but the right fix may be to fix the class
+    # of these things?
+    if isinstance(o, SexpVector):
         if 'data.frame' in o.rclass:
             # R "factor" vectors will not convert well by default
             # (will become integers), so we build a temporary list o2
@@ -106,40 +106,31 @@ def ri2numpy(o):
                 res = numpy.rec.fromarrays(o2)
             else:
                 res = numpy.rec.fromarrays(o2, names=tuple(names))
+        elif (o.typeof in _vectortypes) and (o.typeof != VECSXP):
+            res = numpy.asarray(o)
         else:
             # not a data.frame, yet is it still possible to convert it
             res = ro.default_ri2ro(o)
-    elif (o.typeof in _vectortypes) and (o.typeof != VECSXP):
-        res = numpy.asarray(o)
     else:
         res = ro.default_ri2ro(o)
+
     return res
 
 
 def activate():
-    global original_py2ri, original_ri2ro, original_py2ro
-
-    # If module is already activated, there is nothing to do
-    if original_py2ri: 
-        return
-
-    original_py2ri = conversion.py2ri
-    original_ri2ro = conversion.ri2ro
-    original_py2ro = conversion.py2ro
+    '''Set conversion paths back to numpy2ri versions
 
+    This will straightforwardly override an existing numpy2ri.activate()
+    '''
     conversion.py2ri = numpy2ri
-    conversion.ri2ro = ri2numpy 
+    conversion.ri2ro = ri2numpy
     conversion.py2ro = numpy2ro
 
 def deactivate():
-    global original_py2ri, original_ri2ro, original_py2ro
+    '''Set conversion paths back to robjects defaults
 
-    # If module has never been activated or already deactivated,
-    # there is nothing to do
-    if not original_py2ri:
-        return
-
-    conversion.py2ri = original_py2ri
-    conversion.ri2ro = original_ri2ro
-    conversion.py2ro = original_py2ro
-    original_py2ri = original_ri2ro = original_py2ro = None
+    Note that this will also revert, e.g., pandas2ri.activate()
+    '''
+    conversion.py2ri = conversion.default_py2ri
+    conversion.ri2ro = conversion.default_ri2ro
+    conversion.py2ro = conversion.default_py2ro
