@@ -105,6 +105,9 @@ class ImportrTestCase(unittest.TestCase):
         self.assertTrue(isinstance(datasets, robjects.packages.Package))
         self.assertTrue(isinstance(datasets.__rdata__, 
                                    robjects.packages.PackageData))
+        self.assertTrue(isinstance(robjects.packages.data(datasets), 
+                                   robjects.packages.PackageData))
+        
 
 
         
@@ -114,11 +117,21 @@ class WherefromTestCase(unittest.TestCase):
         rnorm_pack = robjects.packages.wherefrom('rnorm')
         self.assertEqual('package:stats',
                           rnorm_pack.do_slot('name')[0])
+
+class InstalledPackagesTestCase(unittest.TestCase):
+    def testNew(self):
+        instapacks = robjects.packages.InstalledPackages()
+        res = instapacks.isinstalled('foo')
+        self.assertTrue(isinstance(res, bool))
+        ncols = len(instapacks.colnames)
+        for row in instapacks:
+            self.assertEqual(ncols, len(row))
         
 def suite():
     suite = unittest.TestLoader().loadTestsFromTestCase(PackagesTestCase)
     suite.addTest(unittest.TestLoader().loadTestsFromTestCase(ImportrTestCase))
     suite.addTest(unittest.TestLoader().loadTestsFromTestCase(WherefromTestCase))
+    suite.addTest(unittest.TestLoader().loadTestsFromTestCase(InstalledPackagesTestCase))
     suite.addTest(unittest.TestLoader().loadTestsFromTestCase(SignatureTranslatedAnonymousPackagesTestCase))
     return suite
 
