@@ -74,7 +74,7 @@ class PandasConversionsTestCase(unittest.TestCase):
         s = s.split('\n')
         self.assertEqual('[Array, Array, Array, FactorV..., FactorV...]', s[1].strip())
 
-    def testPandas2ri(self):
+    def testRi2pandas(self):
         rdataf = robjects.r('data.frame(a=1:2, b=I(c("a", "b")), c=c("a", "b"))')
         pandas_df = rpyp.ri2pandas(rdataf)
         self.assertIsInstance(pandas_df, pandas.DataFrame)
@@ -82,6 +82,20 @@ class PandasConversionsTestCase(unittest.TestCase):
         self.assertEquals(pandas_df['a'].dtype, numpy.dtype('int32'))
         self.assertEquals(pandas_df['b'].dtype, numpy.dtype('O'))
         self.assertEquals(pandas_df['c'].dtype, numpy.dtype('O'))
+    
+    def testRi2pandas_issue207(self):
+        d = robjects.DataFrame({'x': 1})
+        rpyp.activate()
+        try:
+            ok = True
+            robjects.globalenv['d'] = d
+        except ValueError:
+            ok = False
+        finally:
+            rpyp.deactivate()
+            if 'd' in robjects.globalenv:
+                del(robjects.globalenv['d'])
+        self.assertTrue(ok)
 
 def suite():
     if has_pandas:
